throttle outgoing LASTSEEN packets to at most one per second for a given seq# release_2_0_14
authorbodea <bodea>
Thu, 6 Jan 2005 01:39:22 +0000 (01:39 +0000)
committerbodea <bodea>
Thu, 6 Jan 2005 01:39:22 +0000 (01:39 +0000)
Changes
cluster.c
l2tpns.h
l2tpns.spec

diff --git a/Changes b/Changes
index 9eaca00..75d052f 100644 (file)
--- a/Changes
+++ b/Changes
@@ -1,7 +1,4 @@
-* Mon Dec 20 2004 Brendan O'Dea <bod@optusnet.com.au> 2.1.0
-- Add IPv6 support from Jonathan McDowell (work in progress).
-- Sanity check that cluster_send_session is not called from a child
-  process.
+* Mon Dec 20 2004 Brendan O'Dea <bod@optusnet.com.au> 2.0.14
 - Throttle outgoing LASTSEEN packets to at most one per second for a
   given seq#.
 
index 4035f49..093d944 100644 (file)
--- a/cluster.c
+++ b/cluster.c
@@ -1,6 +1,6 @@
 // L2TPNS Clustering Stuff
 
-char const *cvs_id_cluster = "$Id: cluster.c,v 1.28 2004/12/22 05:30:58 bodea Exp $";
+char const *cvs_id_cluster = "$Id: cluster.c,v 1.26.2.1 2005/01/06 01:39:23 bodea Exp $";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -38,12 +38,11 @@ char const *cvs_id_cluster = "$Id: cluster.c,v 1.28 2004/12/22 05:30:58 bodea Ex
  */
 
 // Module variables.
-int cluster_sockfd = 0;                        // The filedescriptor for the cluster communications port.
+int cluster_sockfd = 0;                // The filedescriptor for the cluster communications port.
 
 in_addr_t my_address = 0;              // The network address of my ethernet port.
 static int walk_session_number = 0;    // The next session to send when doing the slow table walk.
 static int walk_tunnel_number = 0;     // The next tunnel to send when doing the slow table walk.
-int forked = 0;                                // Sanity check: CLI must not diddle with heartbeat table
 
 #define MAX_HEART_SIZE (8192)  // Maximum size of heartbeat packet. Must be less than max IP packet size :)
 #define MAX_CHANGES  (MAX_HEART_SIZE/(sizeof(sessiont) + sizeof(int) ) - 2)    // Assumes a session is the biggest type!
@@ -867,11 +866,6 @@ int cluster_send_session(int sid)
                return -1;
        }
 
-       if (forked) {
-               LOG(0, sid, 0, "cluster_send_session called from child process!\n");
-               return -1;
-       }
-
        return type_changed(C_CSESSION, sid);
 }
 
index ee5fe4a..8c3e4e6 100644 (file)
--- a/l2tpns.h
+++ b/l2tpns.h
@@ -1,5 +1,5 @@
 // L2TPNS Global Stuff
-// $Id: l2tpns.h,v 1.50 2004/12/18 01:20:05 bodea Exp $
+// $Id: l2tpns.h,v 1.49.2.1 2005/01/06 01:39:23 bodea Exp $
 
 #ifndef __L2TPNS_H__
 #define __L2TPNS_H__
@@ -15,7 +15,7 @@
 #include <sys/types.h>
 #include <libcli.h>
 
-#define VERSION        "2.1.0"
+#define VERSION        "2.0.14"
 
 // Limits
 #define MAXTUNNEL      500             // could be up to 65535
 #define        L2TPPORT        1701            // L2TP port
 #define RADPORT                1645            // old radius port...
 #define        PKTARP          0x0806          // ARP packet type
-#define        PKTIP           0x0800          // IPv4 packet type
-#define        PKTIPV6         0x86DD          // IPv6 packet type
+#define        PKTIP           0x0800          // IP packet type
+#define PSEUDOMAC      0x0200          // pseudo MAC prefix (local significant MAC)
 #define        PPPPAP          0xC023
 #define        PPPCHAP         0xC223
 #define        PPPLCP          0xC021
 #define        PPPIPCP         0x8021
-#define        PPPIPV6CP       0x8057
 #define        PPPCCP          0x80FD
 #define PPPIP          0x0021
-#define PPPIPV6                0x0057
 #define PPPMP          0x003D
 #define MIN_IP_SIZE    0x19
 enum
@@ -210,8 +208,6 @@ sessiont;
 #define SF_IPCP_ACKED  1       // Has this session seen an IPCP Ack?
 #define SF_LCP_ACKED   2       // LCP negotiated
 #define SF_CCP_ACKED   4       // CCP negotiated
-#define SF_IPV6CP_ACKED        8       // IPv6 negotiated
-#define SF_IPV6_NACKED 16      // IPv6 rejected
 
 typedef struct
 {
@@ -484,7 +480,7 @@ typedef struct
 #endif
 } configt;
 
-enum config_typet { INT, STRING, UNSIGNED_LONG, SHORT, BOOL, IPv4, IPv6, MAC };
+enum config_typet { INT, STRING, UNSIGNED_LONG, SHORT, BOOL, IP, MAC };
 typedef struct
 {
        char *key;
index 424fd52..b3af7ad 100644 (file)
@@ -1,6 +1,6 @@
 Summary: A high-speed clustered L2TP LNS
 Name: l2tpns
-Version: 2.1.0
+Version: 2.0.14
 Release: 1
 Copyright: GPL
 Group: System Environment/Daemons
@@ -43,5 +43,5 @@ rm -rf %{buildroot}
 %attr(644,root,root) /usr/share/man/man[58]/*
 
 %changelog
-* Mon Dec 20 2004 Brendan O'Dea <bod@optusnet.com.au> 2.1.0-1
-- 2.1.0 release, see /usr/share/doc/l2tpns-2.1.0/Changes
+* Mon Dec 20 2004 Brendan O'Dea <bod@optusnet.com.au> 2.0.14-1
+- 2.0.14 release, see /usr/share/doc/l2tpns-2.0.14/Changes